model

package
v0.3.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 1, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PhaseType

type PhaseType string

PhaseType describes how a phase should be executed.

const (
	// PhaseTypeConstant represents a constant arrival-rate phase.
	PhaseTypeConstant PhaseType = "constant"
	// PhaseTypeRamp represents a phase where arrival rate changes linearly from From to To.
	PhaseTypeRamp PhaseType = "ramp"
	// PhaseTypeStep represents a phase where arrival rate moves from From to To in discrete steps.
	PhaseTypeStep PhaseType = "step"
	// PhaseTypeSpike represents a phase with a temporary spike from From to To.
	PhaseTypeSpike PhaseType = "spike"
)

Jump to